==> haskell-byteable-0.1.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-8StI3PhRPjVAHxdIrDquyO
key:                  byteable-0.1.1-8StI3PhRPjVAHxdIrDquyO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  a1717535d28ec6e6447786b1c0a6669c
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-8.8.1/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-8StI3PhRPjVAHxdIrDquyO
depends:              base-4.13.0.0 bytestring-0.10.9.0
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs
key:                  byteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  a1e02f60758492a5c0fa570a35aecaa2
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-8.8.2/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs
depends:              base-4.13.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
